@@ -7,12 +7,15 @@ so some experimentation will probably be needed to choose the correct one.
 """
 
 import logging
-import os
 import platform
 import requests
 import socket
-import fcntl
+try:
+    import fcntl
+except ImportError:
+    fcntl = None  # type: ignore
 import struct
+import typeguard
 import psutil
 
 from typing import Set, List, Callable
@@ -28,11 +31,18 @@ def address_by_route() -> str:
        not reachable from workers.
     """
     logger.debug("Finding address by querying local routing table")
-    addr = os.popen("/sbin/ip route get 8.8.8.8 | awk '{print $NF;exit}'").read().strip()
+
+    # original author unknown
+    import socket
+    s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
+    s.connect(("8.8.8.8", 80))
+    addr = s.getsockname()[0]
+    s.close()
     logger.debug("Address found: {}".format(addr))
     return addr
 
 
+@typeguard.typechecked
 def address_by_query(timeout: float = 30) -> str:
     """Finds an address for the local host by querying ipify. This may
        return an unusable value when the host is behind NAT, or when the
@@ -66,6 +76,7 @@ def address_by_hostname() -> str:
     return addr
 
 
+@typeguard.typechecked
 def address_by_interface(ifname: str) -> str:
     """Returns the IP address of the given interface name, e.g. 'eth0'
 
@@ -77,6 +88,7 @@ def address_by_interface(ifname: str) -> str:
         Name of the interface whose address is to be returned. Required.
 
     """
+    assert fcntl is not None, "This function is not supported on your OS."
     s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
     return socket.inet_ntoa(fcntl.ioctl(
         s.fileno(),
