@@ -12,6 +12,7 @@ import threading
 import sys
 import datetime
 from getpass import getuser
+from typeguard import typechecked
 from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple
 from uuid import uuid4
 from socket import gethostname
@@ -32,8 +33,10 @@ from parsl.dataflow.rundirs import make_rundir
 from parsl.dataflow.states import States, FINAL_STATES, FINAL_FAILURE_STATES
 from parsl.dataflow.taskrecord import TaskRecord
 from parsl.usage_tracking.usage import UsageTracker
+from parsl.executors.base import ParslExecutor
 from parsl.executors.status_handling import BlockProviderExecutor
 from parsl.executors.threads import ThreadPoolExecutor
+from parsl.monitoring import MonitoringHub
 from parsl.process_loggers import wrap_with_logs
 from parsl.providers.base import JobStatus, JobState
 from parsl.utils import get_version, get_std_fname_mode, get_all_checkpoints
@@ -62,7 +65,8 @@ class DataFlowKernel(object):
 
     """
 
-    def __init__(self, config=Config()):
+    @typechecked
+    def __init__(self, config: Config = Config()) -> None:
         """Initialize the DataFlowKernel.
 
         Parameters
@@ -75,10 +79,6 @@ class DataFlowKernel(object):
         # this will be used to check cleanup only happens once
         self.cleanup_called = False
 
-        if isinstance(config, dict):
-            raise ConfigurationError(
-                    'Expected `Config` class, received dictionary. For help, '
-                    'see http://parsl.readthedocs.io/en/stable/stubs/parsl.config.Config.html')
         self._config = config
         self.run_dir = make_rundir(config.run_dir)
 
@@ -100,7 +100,9 @@ class DataFlowKernel(object):
         # Monitoring
         self.run_id = str(uuid4())
 
+        self.monitoring: Optional[MonitoringHub]
         self.monitoring = config.monitoring
+
         # hub address and port for interchange to connect
         self.hub_address = None  # type: Optional[str]
         self.hub_interchange_port = None  # type: Optional[int]
@@ -175,10 +177,12 @@ class DataFlowKernel(object):
         # flowcontrol.add_executors.
         self.flowcontrol = FlowControl(self)
 
-        self.executors = {}
+        self.executors: Dict[str, ParslExecutor] = {}
+
         self.data_manager = DataManager(self)
         parsl_internal_executor = ThreadPoolExecutor(max_threads=config.internal_tasks_max_threads, label='_parsl_internal')
-        self.add_executors(config.executors + [parsl_internal_executor])
+        self.add_executors(config.executors)
+        self.add_executors([parsl_internal_executor])
 
         if self.checkpoint_mode == "periodic":
             if config.checkpoint_period is None:
@@ -489,7 +493,7 @@ class DataFlowKernel(object):
         return result
 
     def wipe_task(self, task_id: int) -> None:
-        """ Remove task with task_id from the internal tasks table
+        """Remove task with task_id from the internal tasks table
         """
         if self.config.garbage_collect:
             del self.tasks[task_id]
@@ -984,7 +988,7 @@ class DataFlowKernel(object):
         logger.info("End of summary")
 
     def _create_remote_dirs_over_channel(self, provider, channel):
-        """ Create script directories across a channel
+        """Create script directories across a channel
 
         Parameters
         ----------
