@@ -9,6 +9,10 @@ We have two basic types of futures:
 from concurrent.futures import Future
 import logging
 import threading
+from typing import Optional, Sequence
+
+from parsl.app.futures import DataFuture
+from parsl.dataflow.taskrecord import TaskRecord
 
 logger = logging.getLogger(__name__)
 
@@ -34,7 +38,7 @@ class AppFuture(Future):
     """An AppFuture wraps a sequence of Futures which may fail and be retried.
 
     The AppFuture will wait for the DFK to provide a result from an appropriate
-    parent future, through `parent_callback`. It will set its result to the
+    parent future, through ``parent_callback``. It will set its result to the
     result of that parent future, if that parent future completes without an
     exception. This result setting should cause .result(), .exception() and done
     callbacks to fire as expected.
@@ -55,7 +59,7 @@ class AppFuture(Future):
 
     """
 
-    def __init__(self, task_def):
+    def __init__(self, task_def: TaskRecord) -> None:
         """Initialize the AppFuture.
 
         Args:
@@ -66,28 +70,29 @@ class AppFuture(Future):
         """
         super().__init__()
         self._update_lock = threading.Lock()
+        self._outputs: Sequence[DataFuture]
         self._outputs = []
         self.task_def = task_def
 
     @property
-    def stdout(self):
+    def stdout(self) -> Optional[str]:
         return self.task_def['kwargs'].get('stdout')
 
     @property
-    def stderr(self):
+    def stderr(self) -> Optional[str]:
         return self.task_def['kwargs'].get('stderr')
 
     @property
-    def tid(self):
+    def tid(self) -> int:
         return self.task_def['id']
 
-    def cancel(self):
+    def cancel(self) -> bool:
         raise NotImplementedError("Cancel not implemented")
 
-    def cancelled(self):
+    def cancelled(self) -> bool:
         return False
 
-    def task_status(self):
+    def task_status(self) -> str:
         """Returns the status of the task that will provide the value
            for this future.  This may not be in-sync with the result state
            of this future - for example, task_status might return 'done' but
@@ -111,10 +116,5 @@ class AppFuture(Future):
         return self.task_def['status'].name
 
     @property
-    def outputs(self):
+    def outputs(self) -> Sequence[DataFuture]:
         return self._outputs
-
-    def __repr__(self):
-        return '<%s super=%s>' % (
-            self.__class__.__name__,
-            super().__repr__())
