@@ -2,12 +2,10 @@ from parsl.executors.threads import ThreadPoolExecutor
 from parsl.executors.workqueue.executor import WorkQueueExecutor
 from parsl.executors.high_throughput.executor import HighThroughputExecutor
 from parsl.executors.extreme_scale.executor import ExtremeScaleExecutor
-from parsl.executors.low_latency.executor import LowLatencyExecutor
 from parsl.executors.flux.executor import FluxExecutor
 
 __all__ = ['ThreadPoolExecutor',
            'HighThroughputExecutor',
            'ExtremeScaleExecutor',
-           'LowLatencyExecutor',
            'WorkQueueExecutor',
            'FluxExecutor']
