@@ -117,8 +117,14 @@ class WorkQueueExecutor(BlockProviderExecutor, putils.RepresentationMixin):
 
         port: int
             TCP port on Parsl submission machine for Work Queue workers
-            to connect to. Workers will specify this port number when
-            trying to connect to Parsl. Default is 9123.
+            to connect to. Workers will connect to Parsl using this port.
+
+            If 0, Work Queue will allocate a port number automatically.
+            In this case, environment variables can be used to influence the
+            choice of port, documented here:
+            https://ccl.cse.nd.edu/software/manuals/api/html/work__queue_8h.html#a21714a10bcdfcf5c3bd44a96f5dcbda6
+
+            Default: 0.
 
         env: dict{str}
             Dictionary that contains the environmental variables that
@@ -307,6 +313,8 @@ class WorkQueueExecutor(BlockProviderExecutor, putils.RepresentationMixin):
 
         logger.debug("Starting WorkQueueExecutor")
 
+        self._port_mailbox = multiprocessing.Queue()
+
         # Create a Process to perform WorkQueue submissions
         submit_process_kwargs = {"task_queue": self.task_queue,
                                  "launch_cmd": self.launch_cmd,
@@ -322,7 +330,9 @@ class WorkQueueExecutor(BlockProviderExecutor, putils.RepresentationMixin):
                                  "port": self.port,
                                  "wq_log_dir": self.wq_log_dir,
                                  "project_password_file": self.project_password_file,
-                                 "project_name": self.project_name}
+                                 "project_name": self.project_name,
+                                 "port_mailbox": self._port_mailbox
+                                 }
         self.submit_process = multiprocessing.Process(target=_work_queue_submit_wait,
                                                       name="WorkQueue-Submit-Process",
                                                       kwargs=submit_process_kwargs)
@@ -335,6 +345,10 @@ class WorkQueueExecutor(BlockProviderExecutor, putils.RepresentationMixin):
         self.submit_process.start()
         self.collector_thread.start()
 
+        self._chosen_port = self._port_mailbox.get(timeout=60)
+
+        logger.debug(f"Chosen listening port is {self._chosen_port}")
+
         # Initialize scaling for the provider
         self.initialize_scaling()
 
@@ -501,7 +515,7 @@ class WorkQueueExecutor(BlockProviderExecutor, putils.RepresentationMixin):
         if self.project_name:
             worker_command += ' -M {}'.format(self.project_name)
         else:
-            worker_command += ' {} {}'.format(self.address, self.port)
+            worker_command += ' {} {}'.format(self.address, self._chosen_port)
 
         logger.debug("Using worker command: {}".format(worker_command))
         return worker_command
@@ -650,7 +664,7 @@ class WorkQueueExecutor(BlockProviderExecutor, putils.RepresentationMixin):
         return 1
 
     def scale_in(self, count):
-        """Scale in method. Not implemented.
+        """Scale in method.
         """
         # Obtain list of blocks to kill
         to_kill = list(self.blocks.keys())[:count]
@@ -683,13 +697,6 @@ class WorkQueueExecutor(BlockProviderExecutor, putils.RepresentationMixin):
         logger.debug("Work Queue shutdown completed")
         return True
 
-    def run_dir(self, value=None):
-        """Path to the run directory.
-        """
-        if value is not None:
-            self._run_dir = value
-        return self._run_dir
-
     @wrap_with_logs
     def _collect_work_queue_results(self):
         """Sets the values of tasks' futures of tasks completed by work queue.
@@ -730,7 +737,8 @@ class WorkQueueExecutor(BlockProviderExecutor, putils.RepresentationMixin):
 
 
 @wrap_with_logs
-def _work_queue_submit_wait(task_queue=multiprocessing.Queue(),
+def _work_queue_submit_wait(port_mailbox=None,
+                            task_queue=multiprocessing.Queue(),
                             launch_cmd=None,
                             env=None,
                             collector_queue=multiprocessing.Queue(),
@@ -769,10 +777,13 @@ def _work_queue_submit_wait(task_queue=multiprocessing.Queue(),
     # Create WorkQueue queue object
     logger.debug("Creating WorkQueue Object")
     try:
-        logger.debug("Listening on port {}".format(port))
+        logger.debug("Requested port {}".format(port))
         q = WorkQueue(port, debug_log=wq_debug_log)
+        port_mailbox.put(q.port)
+        logger.debug("Listening on port {}".format(q.port))
     except Exception as e:
         logger.error("Unable to create WorkQueue object: {}".format(e))
+        port_mailbox.put(None)
         raise e
 
     # Specify WorkQueue queue attributes
