@@ -6,36 +6,8 @@ class ExecutionProviderException(Exception):
     pass
 
 
-class OptionalModuleMissing(ExecutionProviderException):
-    ''' Error raised a required module is missing for a optional/extra provider
-    '''
-
-    def __init__(self, module_names, reason):
-        self.module_names = module_names
-        self.reason = reason
-
-    def __repr__(self):
-        return "Unable to Initialize provider.Missing:{0},  Reason:{1}".format(
-            self.module_names, self.reason
-        )
-
-
-class ChannelRequired(ExecutionProviderException):
-    ''' Execution provider requires a channel.
-    '''
-
-    def __init__(self, provider, reason):
-        self.provider = provider
-        self.reason = reason
-
-    def __repr__(self):
-        return "Unable to Initialize provider.Provider:{0}, Reason:{1}".format(
-            self.provider, self.reason
-        )
-
-
 class ScaleOutFailed(ExecutionProviderException):
-    ''' Generic catch. Scale out failed in the submit phase on the provider side
+    ''' Scale out failed in the submit phase on the provider side
     '''
 
     def __init__(self, provider, reason):
@@ -68,3 +40,21 @@ class ScriptPathError(ExecutionProviderException):
 
     def __repr__(self):
         return "Unable to write submit script:{0} Reason:{1}".format(self.script_path, self.reason)
+
+
+class SubmitException(ExecutionProviderException):
+    '''Raised by the submit() method of a provider if there is an error in launching a task.
+    '''
+
+    def __init__(self, task_name, message, stdout=None, stderr=None):
+        self.task_name = task_name
+        self.message = message
+        self.stdout = stdout
+        self.stderr = stderr
+
+    def __repr__(self):
+        # TODO: make this more user-friendly
+        return "Cannot launch task {0}: {1}; stdout={2}, stderr={3}".format(self.task_name,
+                                                                            self.message,
+                                                                            self.stdout,
+                                                                            self.stderr)
