@@ -142,7 +142,7 @@ class LSFProvider(ClusterProvider, RepresentationMixin):
         self.worker_init = worker_init
 
     def _status(self):
-        ''' Internal: Do not call. Returns the status list for a list of job_ids
+        '''Returns the status list for a list of job_ids
 
         Args:
               self
