@@ -2,10 +2,8 @@
 
 from parsl.config import Config
 from parsl.executors import HighThroughputExecutor
-from parsl.addresses import address_by_hostname
 from parsl.launchers import MpiRunLauncher
 from parsl.providers import CobaltProvider
-from parsl.tests.utils import get_rundir
 
 # If you are a developer running tests, make sure to update parsl/tests/configs/user_opts.py
 # If you are a user copying-and-pasting this as an example, make sure to either
@@ -20,7 +18,6 @@ config = Config(
             label="cooley_htex",
             worker_debug=False,
             cores_per_worker=1,
-            address=address_by_hostname(),
             provider=CobaltProvider(
                 queue='debug',
                 account=user_opts['cooley']['account'],
@@ -35,6 +32,5 @@ config = Config(
                 walltime='00:10:00',
             ),
         )
-    ],
-    run_dir=get_rundir(),
+    ]
 )
