@@ -22,5 +22,5 @@ config = Config(
             ),
         )
     ],
-    strategy=None,
+    strategy='none',
 )
