@@ -4,8 +4,10 @@ from parsl.app.app import python_app
 from parsl.tests.configs.htex_local import fresh_config
 
 
-local_config = fresh_config()
-local_config.executors[0].init_blocks = 0
+def local_config():
+    c = fresh_config()
+    c.executors[0].init_blocks = 0
+    return c
 
 
 @python_app
