@@ -11,18 +11,13 @@ def get_num(first, second):
 
 
 def test_fibonacci(num=3):
-    x1 = 0
-    x2 = 1
     counter = 0
     results = []
     results.append(0)
     results.append(1)
     while counter < num - 2:
         counter += 1
-        results.append(get_num(x1, x2))
-        temp = x2
-        x2 = get_num(x1, x2)
-        x1 = temp
+        results.append(get_num(results[counter - 1], results[counter]))
     for i in range(len(results)):
         if isinstance(results[i], int):
             print(results[i])
