@@ -1,7 +1,6 @@
 from parsl import python_app
 import pytest
-from parsl.tests.configs.htex_local import fresh_config
-local_config = fresh_config()
+from parsl.tests.configs.htex_local import fresh_config as local_config
 
 
 @python_app
