@@ -3,10 +3,7 @@ import pytest
 from parsl.app.app import python_app
 from parsl.data_provider.files import File
 
-from parsl.tests.configs.local_threads_http_in_task import config
-
-
-local_config = config
+from parsl.tests.configs.local_threads_http_in_task import fresh_config as local_config
 
 
 @python_app
