@@ -3,20 +3,30 @@ import logging
 import os
 import shlex
 import subprocess
+import threading
 import time
 import typeguard
 from contextlib import contextmanager
-from typing import List
+from typing import List, Tuple, Union, Generator, IO, AnyStr, Dict
 
 import parsl
 from parsl.version import VERSION
 
+
+try:
+    import setproctitle as setproctitle_module
+except ImportError:
+    _setproctitle_enabled = False
+else:
+    _setproctitle_enabled = True
+
+
 logger = logging.getLogger(__name__)
 
 
 @typeguard.typechecked
 def get_version() -> str:
-    version = parsl.__version__
+    version = parsl.__version__  # type: str
     work_tree = os.path.dirname(os.path.dirname(__file__))
     git_dir = os.path.join(work_tree, '.git')
     if os.path.exists(git_dir):
@@ -26,7 +36,7 @@ def get_version() -> str:
             head = subprocess.check_output(cmd, env=env).strip().decode('utf-8')
             diff = subprocess.check_output(shlex.split('git diff HEAD'), env=env)
             status = 'dirty' if diff else 'clean'
-            version = '{v}-{head}-{status}'.format(v=VERSION, head=head, status=status)
+            version = f'{VERSION}-{head}-{status}'
         except Exception:
             pass
 
@@ -35,18 +45,13 @@ def get_version() -> str:
 
 @typeguard.typechecked
 def get_all_checkpoints(rundir: str = "runinfo") -> List[str]:
-    """Finds the checkpoints from all last runs.
-
-    Note that checkpoints are incremental, and this helper will not find
-    previous checkpoints from earlier than the most recent run. It probably
-    should be made to do so.
+    """Finds the checkpoints from all runs in the rundir.
 
     Kwargs:
        - rundir(str) : Path to the runinfo directory
 
     Returns:
-       - a list suitable for the checkpointFiles parameter of the DataFlowKernel
-         constructor
+       - a list suitable for the checkpoint_files parameter of `Config`
 
     """
 
@@ -59,7 +64,7 @@ def get_all_checkpoints(rundir: str = "runinfo") -> List[str]:
 
     for runid in dirs:
 
-        checkpoint = os.path.abspath('{}/{}/checkpoint'.format(rundir, runid))
+        checkpoint = os.path.abspath(f'{rundir}/{runid}/checkpoint')
 
         if os.path.isdir(checkpoint):
             checkpoints.append(checkpoint)
@@ -72,15 +77,15 @@ def get_last_checkpoint(rundir: str = "runinfo") -> List[str]:
     """Finds the checkpoint from the last run, if one exists.
 
     Note that checkpoints are incremental, and this helper will not find
-    previous checkpoints from earlier than the most recent run. It probably
-    should be made to do so.
+    previous checkpoints from earlier than the most recent run. If you
+    want that behaviour, see `get_all_checkpoints`.
 
     Kwargs:
        - rundir(str) : Path to the runinfo directory
 
     Returns:
-     - a list suitable for the checkpointFiles parameter of the DataFlowKernel
-       constructor, with 0 or 1 elements
+     - a list suitable for the checkpoint_files parameter of `Config`,
+       with 0 or 1 elements
 
     """
     if not os.path.isdir(rundir):
@@ -92,7 +97,7 @@ def get_last_checkpoint(rundir: str = "runinfo") -> List[str]:
         return []
 
     last_runid = dirs[-1]
-    last_checkpoint = os.path.abspath('{}/{}/checkpoint'.format(rundir, last_runid))
+    last_checkpoint = os.path.abspath(f'{rundir}/{last_runid}/checkpoint')
 
     if(not(os.path.isdir(last_checkpoint))):
         return []
@@ -100,7 +105,7 @@ def get_last_checkpoint(rundir: str = "runinfo") -> List[str]:
     return [last_checkpoint]
 
 
-def get_std_fname_mode(fdname, stdfspec):
+def get_std_fname_mode(fdname: str, stdfspec: Union[str, Tuple[str, str]]) -> Tuple[str, str]:
     import parsl.app.errors as pe
     if stdfspec is None:
         return None, None
@@ -109,17 +114,22 @@ def get_std_fname_mode(fdname, stdfspec):
         mode = 'a+'
     elif isinstance(stdfspec, tuple):
         if len(stdfspec) != 2:
-            raise pe.BadStdStreamFile("std descriptor %s has incorrect tuple length %s" % (fdname, len(stdfspec)), TypeError('Bad Tuple Length'))
+            msg = (f"std descriptor {fdname} has incorrect tuple length "
+                   f"{len(stdfspec)}")
+            raise pe.BadStdStreamFile(msg, TypeError('Bad Tuple Length'))
         fname, mode = stdfspec
         if not isinstance(fname, str) or not isinstance(mode, str):
-            raise pe.BadStdStreamFile("std descriptor %s has unexpected type %s" % (fdname, str(type(stdfspec))), TypeError('Bad Tuple Type'))
+            msg = (f"std descriptor {fdname} has unexpected type "
+                   f"{type(stdfspec)}")
+            raise pe.BadStdStreamFile(msg, TypeError('Bad Tuple Type'))
     else:
-        raise pe.BadStdStreamFile("std descriptor %s has unexpected type %s" % (fdname, str(type(stdfspec))), TypeError('Bad Tuple Type'))
+        msg = f"std descriptor {fdname} has unexpected type {type(stdfspec)}"
+        raise pe.BadStdStreamFile(msg, TypeError('Bad Tuple Type'))
     return fname, mode
 
 
 @contextmanager
-def wait_for_file(path, seconds=10):
+def wait_for_file(path: str, seconds: int = 10) -> Generator[None, None, None]:
     for i in range(0, int(seconds * 100)):
         time.sleep(seconds / 100.)
         if os.path.exists(path):
@@ -128,7 +138,7 @@ def wait_for_file(path, seconds=10):
 
 
 @contextmanager
-def time_limited_open(path, mode, seconds=1):
+def time_limited_open(path: str, mode: str, seconds: int = 1) -> Generator[IO[AnyStr], None, None]:
     with wait_for_file(path, seconds):
         logger.debug("wait_for_file yielded")
     f = open(path, mode)
@@ -136,7 +146,7 @@ def time_limited_open(path, mode, seconds=1):
     f.close()
 
 
-def wtime_to_minutes(time_string):
+def wtime_to_minutes(time_string: str) -> int:
     ''' wtime_to_minutes
 
     Convert standard wallclock time string to minutes.
@@ -151,7 +161,9 @@ def wtime_to_minutes(time_string):
     hours, mins, seconds = time_string.split(':')
     total_mins = int(hours) * 60 + int(mins)
     if total_mins < 1:
-        logger.warning("Time string '{}' parsed to {} minutes, less than 1".format(time_string, total_mins))
+        msg = (f"Time string '{time_string}' parsed to {total_mins} minutes, "
+               f"less than 1")
+        logger.warning(msg)
     return total_mins
 
 
@@ -181,8 +193,8 @@ class RepresentationMixin(object):
     """
     __max_width__ = 80
 
-    def __repr__(self):
-        init = self.__init__
+    def __repr__(self) -> str:
+        init = self.__init__  # type: ignore
 
         # This test looks for a single layer of wrapping performed by
         # functools.update_wrapper, commonly used in decorators. This will
@@ -203,8 +215,10 @@ class RepresentationMixin(object):
 
         for arg in argspec.args[1:]:
             if not hasattr(self, arg):
-                template = 'class {} uses {} in the constructor, but does not define it as an attribute'
-                raise AttributeError(template.format(self.__class__.__name__, arg))
+                template = (f'class {self.__class__.__name__} uses {arg} in the'
+                            f' constructor, but does not define it as an '
+                            f'attribute')
+                raise AttributeError(template)
 
         if len(defaults) != 0:
             args = [getattr(self, a) for a in argspec.args[1:-len(defaults)]]
@@ -212,26 +226,48 @@ class RepresentationMixin(object):
             args = [getattr(self, a) for a in argspec.args[1:]]
         kwargs = {key: getattr(self, key) for key in defaults}
 
-        def assemble_multiline(args, kwargs):
-            def indent(text):
+        def assemble_multiline(args: List[str], kwargs: Dict[str, object]) -> str:
+            def indent(text: str) -> str:
                 lines = text.splitlines()
                 if len(lines) <= 1:
                     return text
                 return "\n".join("    " + line for line in lines).strip()
-            args = ["\n    {},".format(indent(repr(a))) for a in args]
-            kwargs = ["\n    {}={}".format(k, indent(repr(v)))
-                      for k, v in sorted(kwargs.items())]
+            args = [f"\n    {indent(repr(a))}," for a in args]
+            kwargsl = [f"\n    {k}={indent(repr(v))}" for k, v in
+                       sorted(kwargs.items())]
 
-            info = "".join(args) + ", ".join(kwargs)
-            return self.__class__.__name__ + "({}\n)".format(info)
+            info = "".join(args) + ", ".join(kwargsl)
+            return self.__class__.__name__ + f"({info}\n)"
 
-        def assemble_line(args, kwargs):
-            kwargs = ['{}={}'.format(k, repr(v)) for k, v in sorted(kwargs.items())]
+        def assemble_line(args: List[str], kwargs: Dict[str, object]) -> str:
+            kwargsl = [f'{k}={repr(v)}' for k, v in sorted(kwargs.items())]
 
-            info = ", ".join([repr(a) for a in args] + kwargs)
-            return self.__class__.__name__ + "({})".format(info)
+            info = ", ".join([repr(a) for a in args] + kwargsl)
+            return self.__class__.__name__ + f"({info})"
 
         if len(assemble_line(args, kwargs)) <= self.__class__.__max_width__:
             return assemble_line(args, kwargs)
         else:
             return assemble_multiline(args, kwargs)
+
+
+class AtomicIDCounter:
+    """A class to allocate counter-style IDs, in a thread-safe way.
+    """
+
+    def __init__(self):
+        self.count = 0
+        self.lock = threading.Lock()
+
+    def get_id(self):
+        with self.lock:
+            new_id = self.count
+            self.count += 1
+            return new_id
+
+
+def setproctitle(title: str) -> None:
+    if _setproctitle_enabled:
+        setproctitle_module.setproctitle(title)
+    else:
+        logger.warn(f"setproctitle not enabled for process {title}")
